@@ -7,15 +7,16 @@ use v5.20;
 use Moo;
 
 use File::ShareDir qw( dist_file );
+use Path::Tiny 0.018 qw( cwd path );
 use Text::Template;
 use Text::Wrap    qw( wrap $columns );
 use Types::Common qw( InstanceOf Maybe NonEmptyStr NonEmptySimpleStr PositiveInt );
 
-use experimental qw( signatures );
+use experimental qw( lexical_subs signatures );
 
 use namespace::autoclean;
 
-our $VERSION = 'v0.1.1';
+our $VERSION = 'v0.2.0';
 
 
 has name => (
@@ -32,6 +33,13 @@ has contact => (
 );
 
 
+has entity => (
+    is      => 'ro',
+    isa     => NonEmptySimpleStr,
+    default => 'project',
+);
+
+
 has policy => (
     is      => 'ro',
     default => 'Contributor_Covenant_1.4',
@@ -40,11 +48,10 @@ has policy => (
 
 has template_path => (
     is      => 'lazy',
-    isa     => Maybe [NonEmptySimpleStr],
+    isa     => InstanceOf ['Path::Tiny'],
+    coerce  => \&path,
     builder => sub($self) {
-        my $dist = __PACKAGE__;
-        $dist =~ s/::/-/g;
-        return dist_file( $dist, $self->policy . ".md.tmpl", );
+        return path( dist_file( __PACKAGE__ =~ s/::/-/gr , $self->policy . ".md.tmpl" ) );
     },
 );
 
@@ -73,18 +80,42 @@ has text => (
     is      => 'lazy',
     isa     => NonEmptyStr,
     builder => sub($self) {
-        $columns = $self->text_columns;
         my $raw = $self->_template->fill_in(
             HASH => {
+                name    => $self->name,
                 contact => $self->contact,
+                entity  => $self->entity,
             }
         );
-        my @lines = map { wrap( "", $_ =~ /^[\*\-]/ ? "  " : "", $_ ) } split /\n/, ( $raw =~ s/[ ][ ]+/ /gr );
+
+        $columns = $self->text_columns;
+        my sub _wrap($line) {
+            return $line if $line =~ /^[ ]{4}/; # ignore preformatted code
+            return wrap( "", $line =~ /^[\*\-](?![\*\-]) ?/ ? "  " : "", $line =~ s/[ ][ ]+/ /gr );
+        }
+
+        my @lines = map { _wrap($_) } split /\n/, $raw;
         return join( "\n", @lines );
 
     }
 );
 
+
+has filename => (
+    is      => 'ro',
+    isa     => NonEmptySimpleStr,
+    coerce  => sub($name) { return path($name)->basename },
+    default => 'CODE_OF_CONDUCT.md',
+);
+
+
+sub save($self, $dir = undef) {
+    my $path = path( $dir // cwd, $self->filename );
+    $path->spew_raw( $self->text );
+    return $path;
+}
+
+
 1;
 
 __END__
@@ -99,19 +130,18 @@ Software::Policy::CodeOfConduct - generate a Code of Conduct policy
 
 =head1 VERSION
 
-version v0.1.1
+version v0.2.0
 
 =head1 SYNOPSIS
 
     my $policy = Software::Policy::CodeOfConduct->new(
-        name    => 'Foo',
-        contact => 'team-foo@example.com',
-        policy  => 'Contributor_Covenant_1.4',
+        name     => 'Foo',
+        contact  => 'team-foo@example.com',
+        policy   => 'Contributor_Covenant_1.4',
+        filename => 'CODE-OF-CONDUCT.md',
     );
 
-    open my $fh, '>', "CODE-OF-CONDUCT.md" or die $!;
-    print {$fh} $policy->text;
-    close $fh;
+    $policy->save($dir); # create CODE-OF-CONDUCT.md in $dir
 
 =head1 DESCRIPTION
 
@@ -133,11 +163,27 @@ The is the contact for the project team about the code of conduct. It should be
 
 It is required.
 
+=head2 entity
+
+A generating name for the project. It defaults to "project" but the original templates used "community".
+
 =head2 policy
 
-This is the policy filename. It defaults to F<Contributor_Covenant_1.4> which is based on
+This is the policy filename. It defaults to "Contributor_Covenant_1.4" which is based on
 L<https://www.contributor-covenant.org/version/1/4/code-of-conduct.html>.
 
+Available policies include
+
+=over
+
+=item "Contributor_Covenant_1.4"
+
+=item "Contributor_Covenant_2.0"
+
+=item "Contributor_Covenant_2.1"
+
+=back
+
 =head2 template_path
 
 This is the path to the template file. If omitted, it will assume it is an included file from L</policy>.
@@ -154,12 +200,35 @@ The default is C<78>.
 
 This is the text generated from the template.
 
+=head2 filename
+
+This is the file to be generated.
+
+This defaults to F<CODE_OF_CONDUCT.md>.
+
+=head1 METHODS
+
+=head2 save
+
+    my $path = $policy->save( $dir );
+
+This saves a file named L</filename> in directory C<$dir>.
+
+If C<$dir> is omitted, then it will save the file in the current directory.
+
 =head1 SOURCE
 
 The development version is on github at L<https://github.com/robrwo/perl-Software-Policy-CodeOfConduct>
 and may be cloned from L<git://github.com/robrwo/perl-Software-Policy-CodeOfConduct.git>
 
-=head1 BUGS
+=head1 SUPPORT
+
+Only the latest version of this module will be supported.
+
+This module requires Perl v5.20 or later.  Future releases may only support Perl versions released in the last ten
+years.
+
+=head2 Reporting Bugs
 
 Please report any bugs or feature requests on the bugtracker website
 L<https://github.com/robrwo/perl-Software-Policy-CodeOfConduct/issues>
@@ -168,6 +237,9 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+If the bug you are reporting has security implications which make it inappropriate to send to a public issue tracker,
+then see F<SECURITY.md> for instructions how to report security vulnerabilities
+
 =head1 AUTHOR
 
 Robert Rothenberg <rrwo@cpan.org>
